package org.acme.microprofile.faulttolerance;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class CoffeeResourceIT extends BaseTest {

}
